EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DebianPackages_IncrementDownloadCount',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Increments the download count for a Debian package.'
GO

IF OBJECT_ID('[DebianPackages_IncrementDownloadCount]') IS NOT NULL DROP PROCEDURE [DebianPackages_IncrementDownloadCount]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [DebianPackages_IncrementDownloadCount]
(
	@Feed_Id INT,
	@Component_Name VARCHAR(255),
	@Package_Name VARCHAR(255),
	@Architecture_Name VARCHAR(255),
	@Version_Text VARCHAR(255)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [DebianPackages]
	   SET [Download_Count] = [Download_Count] + 1,
	       [LastDownloaded_Date] = GETUTCDATE()
	  WHERE [Feed_Id] = @Feed_Id
	    AND [Component_Name] = @Component_Name
	    AND [Package_Name] = @Package_Name
	    AND [Architecture_Name] = @Architecture_Name
	    AND [Version_Text] = @Version_Text

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DebianPackages_IncrementDownloadCount] TO [ProGetUser_Role]
GO