EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ExternalGroups_CreateOrUpdateGroup',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new external group or updates an existing one.'
GO

IF OBJECT_ID('[ExternalGroups_CreateOrUpdateGroup]') IS NOT NULL DROP PROCEDURE [ExternalGroups_CreateOrUpdateGroup]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [ExternalGroups_CreateOrUpdateGroup]
(
	@UserDirectory_Id INT,
	@ExternalGroup_Name NVARCHAR(200),
	@ExternalGroup_Display_Name NVARCHAR(200)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
				FROM [ExternalUsers]
				WITH (UPDLOCK)
			   WHERE [UserDirectory_Id] = @UserDirectory_Id
				 AND [ExternalUser_Name] = @ExternalGroup_Name)
		RAISERROR('Cannot create external group "%s"; there is a user of the same name.', 16, 1, @ExternalGroup_Name)

	IF EXISTS(SELECT *
				FROM [ExternalGroups]
				WITH (UPDLOCK)
			   WHERE [UserDirectory_Id] = @UserDirectory_Id
				 AND [ExternalGroup_Name] = @ExternalGroup_Name)
	BEGIN
		
		UPDATE [ExternalGroups]
		   SET [ExternalGroup_Display_Name] = @ExternalGroup_Display_Name
		 WHERE [UserDirectory_Id] = @UserDirectory_Id
		   AND [ExternalGroup_Name] = @ExternalGroup_Name

	END
	ELSE
	BEGIN

		INSERT INTO [ExternalGroups]
		(
			[UserDirectory_Id],
			[ExternalGroup_Name],
			[ExternalGroup_Display_Name]
		)
		VALUES
		(
			@UserDirectory_Id,
			@ExternalGroup_Name,
			@ExternalGroup_Display_Name
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ExternalGroups_CreateOrUpdateGroup] TO [ProGetUser_Role]
GO