EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NuGetPackagesV2_PullCached',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Pulled_Indicator',
    /* Description_Text        */ 'Changes a cached package to a local package in a feed if it was found.'
GO

IF OBJECT_ID('[NuGetPackagesV2_PullCached]') IS NOT NULL DROP PROCEDURE [NuGetPackagesV2_PullCached]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO


CREATE PROCEDURE [NuGetPackagesV2_PullCached]
(
	@Feed_Id INT,
	@Package_Id VARCHAR(255),
	@Version_Text VARCHAR(255),
	@Pulled_Indicator YNINDICATOR = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	SET @Pulled_Indicator = 'N'

	DECLARE @NuGetPackageV2_Id INT

	SET @NuGetPackageV2_Id = (SELECT [NuGetPackageV2_Id]
	                            FROM [NuGetPackageVersionsV2_Extended]
							   WHERE [Feed_Id] = @Feed_Id
							     AND [Package_Id] = @Package_Id
								 AND [Version_Text] = @Version_Text)

	IF @NuGetPackageV2_Id IS NOT NULL
	BEGIN

		UPDATE [NuGetPackageVersionsV2]
		   SET [Cached_Indicator] = 'N'
		 WHERE [NuGetPackageV2_Id] = @NuGetPackageV2_Id
		   AND [Version_Text] = @Version_Text

		SET @Pulled_Indicator = 'Y'
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [NuGetPackagesV2_PullCached] TO [ProGetUser_Role]